# -*- coding: utf-8 -*-

## This file is part of Videoporama
# Videoporama is a program to make diaporama export in video file
# Copyright (C) 2007-2010  Olivier Ponchaut <opvg@numericable.be> - Dominique Levray

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


import os
import sys
import subprocess
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from xml.dom import minidom
from xml.dom.minidom import Document
from mplayer import *
from GlobalDefines import *
from DefMoviePoint import *
from DocHelpDlg import *


class DefMoviePointDlg(QDialog,Ui_DefMoviePointDlg) :
    def __init__(self,timelineImage,VideoporamaInstance,parent=None):
      super(DefMoviePointDlg, self).__init__(parent)
      self.setupUi(self)
      self.setModal(True)
      self.timelineImage = timelineImage
      self.VideoporamaInstance = VideoporamaInstance
      self.parent = parent
      self.lastDir =  self.VideoporamaInstance.lastDirSound
      self.iconStop = QIcon(QPixmap("icons/player_stop.png"))
      # Add mplayer widget at interface
      vbox = QVBoxLayout(self.grpMP)
      self.videoPlayer = Mplayer(self.VideoporamaInstance ,cheminVideo=[""], taille=(200,150),
            facteurLimitant=Mplayer.HAUTEUR,
            choixWidget=(Mplayer.PAS_PRECEDENT_SUIVANT,Mplayer.CURSEUR_A_PART),
            cheminMPlayer=self.VideoporamaInstance.MP)
      self.videoPlayer.setAudio(False)
      vbox.addWidget(self.videoPlayer)
      # Add video urlfile to mplayer widget
      self.setEditorValue(timelineImage.urlim,                  # Url of the video
          timelineImage.StartVideo,  # Start time in QTime object
          timelineImage.EndVideo)    # Stop time in QTime object

      self.connect(self.buttonBox,SIGNAL("accepted()"),self.VideoporamaInstance.TAB_Movie_DefMoviePointOk)
      self.connect(self.buttonBox,SIGNAL("rejected()"),self.videoPlayer.arretMPlayer)
      self.connect(self.TTstart, SIGNAL("clicked(bool)"), self.setTTstart)
      self.connect(self.Tstart, SIGNAL("clicked(bool)"), self.setTstart)
      self.connect(self.Tend, SIGNAL("clicked(bool)"), self.setTend)
      self.connect(self.TTend, SIGNAL("clicked(bool)"), self.setTTend)
      self.connect(self.start, SIGNAL("clicked(bool)"), self.setStart)
      self.connect(self.breakIn, SIGNAL("timeChanged (QTime)"), self.breakAction)
      self.connect(self.breakOut, SIGNAL("timeChanged (QTime)"), self.breakAction)
      self.connect(self.buttonBox, SIGNAL("helpRequested()"), self.helpWin)
      
      
    def helpWin(self) :
      docw=DocHelp(self.VideoporamaInstance,self.VideoporamaInstance.qtapp.translate("Documentation","en-moviebox.html"),self)
      docw.show()
        
    def setStart(self, state) :
      """Function to start at begin or in point"""
      if state :
        start = QTime(0,0,0).msecsTo(self.breakIn.time())/1000.0
        end = QTime(0,0,0).msecsTo(self.breakOut.time())/1000.0
        self.videoPlayer.setFileToPlay(self.timelineImage.urlim, [start, end])
      else :
        self.videoPlayer.setFileToPlay(self.timelineImage.urlim)
      
    def breakAction(self) :
      if not self.stopMAJ :
        if self.breakOut.time()<(self.breakIn.time()) :
          self.breakOut.setTime(self.breakIn.time())
        self.setStart(self.start.isChecked())
        self.drawTrim()   


    def setEditorValue(self, urlFile, TstartV, TendV) :
      if urlFile != None :
        self.videoPlayer.setFileToPlay(urlFile)
        self.displayInfo()
      self.stopMAJ = 1
      self.breakIn.setTime(TstartV)
      self.breakOut.setTime(TendV)
      self.stopMAJ = 0
      self.setStart(True)
      self.drawTrim()

          
    def setTTstart(self) : 
      self.stopMAJ=1
      self.breakIn.setTime(QTime(0,0,0))
      self.drawTrim()
      self.VideoporamaInstance.App_SetModifiedFlag()
      self.stopMAJ=0
      self.setStart(self.start.isChecked())
      
    def setTstart(self) :
      self.stopMAJ=1
      self.breakIn.setTime(QTime(0,0,0).addMSecs(self.videoPlayer.temps*1000))
      if self.breakOut.time()<(self.breakIn.time()) :
        self.breakOut.setTime(self.breakIn.time())
      self.drawTrim()
      self.VideoporamaInstance.App_SetModifiedFlag()
      self.stopMAJ=0
      self.setStart(self.start.isChecked())

      
    def setTTend(self) : 
      self.stopMAJ=1
      self.breakOut.setTime(self.timelineImage.InitialDurationVideo)
      self.drawTrim()
      self.VideoporamaInstance.App_SetModifiedFlag()      
      self.stopMAJ=0
      self.setStart(self.start.isChecked())
      
    def setTend(self) :
      self.stopMAJ=1    
      self.breakOut.setTime(QTime(0,0,0).addMSecs(self.videoPlayer.temps*1000))
      if self.breakOut.time()<(self.breakIn.time()) :
        self.breakIn.setTime(self.breakOut.time())
      self.drawTrim()
      self.VideoporamaInstance.App_SetModifiedFlag()
      self.stopMAJ=0
      self.setStart(self.start.isChecked())
      
    def drawTrim(self) :
      start = self.breakIn.time()
      stop = self.breakOut.time()
      DrawMovieRuller(self.CustomWidget, start, stop, self.timelineImage.InitialDurationVideo)
      
    def displayInfo(self) :
      QTimeDureeVideo = self.timelineImage.InitialDurationVideo
      self.breakIn.setMaximumTime(QTimeDureeVideo)
      self.breakOut.setMaximumTime(QTimeDureeVideo)
      self.setTTend()
      

